.
[privoxy.git] / cgi.c
diff --git a/cgi.c b/cgi.c
index 73461dd..cc07379 100644 (file)
--- a/cgi.c
+++ b/cgi.c
@@ -1,4 +1,4 @@
-const char cgi_rcs[] = "$Id: cgi.c,v 1.50 2002/03/16 23:54:06 jongfoster Exp $";
+const char cgi_rcs[] = "$Id: cgi.c,v 1.57 2002/03/26 22:29:54 swa Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/cgi.c,v $
@@ -12,7 +12,7 @@ const char cgi_rcs[] = "$Id: cgi.c,v 1.50 2002/03/16 23:54:06 jongfoster Exp $";
  * 
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
- *                Privoxy team.  http://ijbswa.sourceforge.net
+ *                Privoxy team. http://www.privoxy.org/
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and 
@@ -38,6 +38,27 @@ const char cgi_rcs[] = "$Id: cgi.c,v 1.50 2002/03/16 23:54:06 jongfoster Exp $";
  *
  * Revisions   :
  *    $Log: cgi.c,v $
+ *    Revision 1.57  2002/03/26 22:29:54  swa
+ *    we have a new homepage!
+ *
+ *    Revision 1.56  2002/03/24 17:50:46  jongfoster
+ *    Fixing compile error if actions file editor disabled
+ *
+ *    Revision 1.55  2002/03/24 16:55:06  oes
+ *    Making GIF checkerboard transparent
+ *
+ *    Revision 1.54  2002/03/24 16:18:15  jongfoster
+ *    Removing old logo
+ *
+ *    Revision 1.53  2002/03/24 16:06:00  oes
+ *    Correct transparency for checkerboard PNG. Thanks, Magnus!
+ *
+ *    Revision 1.52  2002/03/24 15:23:33  jongfoster
+ *    Name changes
+ *
+ *    Revision 1.51  2002/03/24 13:25:43  swa
+ *    name change related issues
+ *
  *    Revision 1.50  2002/03/16 23:54:06  jongfoster
  *    Adding graceful termination feature, to help look for memory leaks.
  *    If you enable this (which, by design, has to be done by hand
@@ -357,10 +378,10 @@ static const struct cgi_dispatcher cgi_dispatchers[] = {
    { "show-url-info",
          cgi_show_url_info, 
          "Show which actions apply to a URL and why"  },
+#ifdef FEATURE_CGI_EDIT_ACTIONS
    { "toggle",
          cgi_toggle, 
-         "Toggle JunkBuster on or off" },
-#ifdef FEATURE_CGI_EDIT_ACTIONS
+         "Toggle Privoxy on or off" },
    { "edit-actions",
          cgi_edit_actions, 
          "Edit the actions list" },
@@ -448,25 +469,6 @@ static const struct cgi_dispatcher cgi_dispatchers[] = {
 
 #ifdef FEATURE_NO_GIFS
 
-/*
- * "Junkbuster" logo, as a PNG.
- */
-const char image_logo_data[] =
-   "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104"
-   "\122\000\000\000\104\000\000\000\013\001\003\000\000\000\374"
-   "\323\271\110\000\000\000\004\147\101\115\101\000\000\261\217"
-   "\013\374\141\005\000\000\000\006\120\114\124\105\310\310\310"
-   "\000\000\000\062\100\100\345\000\000\000\001\164\122\116\123"
-   "\000\100\346\330\146\000\000\000\001\142\113\107\104\000\210"
-   "\005\035\110\000\000\000\126\111\104\101\124\170\332\143\140"
-   "\200\003\066\006\146\066\006\006\011\124\326\331\315\146\147"
-   "\316\333\174\116\000\262\156\247\347\334\234\071\373\001\220"
-   "\065\373\130\316\035\311\331\015\020\326\161\311\337\014\014"
-   "\151\147\147\247\345\034\236\331\014\144\335\235\155\236\173"
-   "\163\366\154\006\006\233\334\331\162\307\316\363\174\106\330"
-   "\300\000\000\002\127\040\324\250\204\044\102\000\000\000\000"
-   "\111\105\116\104\256\102\140\202";
-
 /*
  * Checkerboard pattern, as a PNG.
  */
@@ -483,37 +485,26 @@ const char image_pattern_data[] =
  * 1x1 transparant PNG.
  */
 const char image_blank_data[] =
-   "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104"
-   "\122\000\000\000\002\000\000\000\002\010\002\000\000\000\375"
-   "\324\232\163\000\000\000\006\142\113\107\104\000\310\000\310"
-   "\000\310\052\045\225\037\000\000\000\027\111\104\101\124\170"
-   "\332\143\374\377\377\377\311\223\047\031\116\234\070\361\377"
-   "\377\177\000\112\335\012\257\162\103\306\335\000\000\000\000"
-   "\111\105\116\104\256\102\140\202o";
+ "\211\120\116\107\015\012\032\012\000\000\000\015\111\110\104\122"
+ "\000\000\000\004\000\000\000\004\010\006\000\000\000\251\361\236"
+ "\176\000\000\000\007\164\111\115\105\007\322\003\013\020\073\070"
+ "\013\025\036\203\000\000\000\011\160\110\131\163\000\000\013\022"
+ "\000\000\013\022\001\322\335\176\374\000\000\000\004\147\101\115"
+ "\101\000\000\261\217\013\374\141\005\000\000\000\033\111\104\101"
+ "\124\170\332\143\070\161\342\304\207\377\377\377\347\302\150\006"
+ "\144\016\210\146\040\250\002\000\042\305\065\221\270\027\131\110"
+ "\000\000\000\000\111\105\116\104\256\102\140\202";
 #else
 
-/*
- * "Junkbuster" logo, as a GIF.
- */
-const char image_logo_data[] =
-   "GIF89aD\000\013\000\360\000\000\000\000\000\377\377\377!"
-   "\371\004\001\000\000\001\000,\000\000\000\000D\000\013\000"
-   "\000\002a\214\217\251\313\355\277\000\200G&K\025\316hC\037"
-   "\200\234\230Y\2309\235S\230\266\206\372J\253<\3131\253\271"
-   "\270\215\342\254\013\203\371\202\264\334P\207\332\020o\266"
-   "N\215I\332=\211\312\3513\266:\026AK)\364\370\365aobr\305"
-   "\372\003S\275\274k2\354\254z\347?\335\274x\306^9\374\276"
-   "\037Q\000\000;";
-
 /*
  * Checkerboard pattern, as a GIF.
  */
 const char image_pattern_data[] =
    "\107\111\106\070\071\141\004\000\004\000\200\000\000\310\310"
-   "\310\377\377\377\041\376\025\111\040\165\163\145\144\040\164"
-   "\157\040\142\145\040\141\040\142\141\156\156\145\162\000\054"
-   "\000\000\000\000\004\000\004\000\000\002\005\104\174\147\270"
-   "\005\000\073";
+   "\310\377\377\377\041\376\016\111\040\167\141\163\040\141\040"
+   "\142\141\156\156\145\162\000\041\371\004\001\012\000\001\000"
+   "\054\000\000\000\000\004\000\004\000\000\002\005\104\174\147"
+   "\270\005\000\073";
 
 /*
  * 1x1 transparant GIF.
@@ -524,7 +515,6 @@ const char image_blank_data[] =
    "\000\001\000\000\002\002D\001\000;";
 #endif
 
-const size_t image_logo_length    = sizeof(image_logo_data) - 1;
 const size_t image_pattern_length = sizeof(image_pattern_data) - 1;
 const size_t image_blank_length   = sizeof(image_blank_data) - 1;
 
@@ -856,15 +846,15 @@ void cgi_init_error_messages(void)
 {
    memset(cgi_error_memory_response, '\0', sizeof(*cgi_error_memory_response));
    cgi_error_memory_response->head =
-      "HTTP/1.0 500 Internal JunkBuster Proxy Error\r\n"
+      "HTTP/1.0 500 Internal Privoxy Error\r\n"
       "Content-Type: text/html\r\n"
       "\r\n";
    cgi_error_memory_response->body =
       "<html>\r\n"
-      "<head><title>500 Internal JunkBuster Proxy Error</title></head>\r\n"
+      "<head><title>500 Internal Privoxy Error</title></head>\r\n"
       "<body>\r\n"
-      "<h1>500 Internal JunkBuster Proxy Error</h1>\r\n"
-      "<p>JunkBuster <b>ran out of memory</b> while processing your request.</p>\r\n"
+      "<h1>500 Internal Privoxy Error</h1>\r\n"
+      "<p>Privoxy <b>ran out of memory</b> while processing your request.</p>\r\n"
       "<p>Please contact your proxy administrator, or try again later</p>\r\n"
       "</body>\r\n"
       "</html>\r\n";
@@ -926,13 +916,13 @@ jb_err cgi_error_no_template(struct client_state *csp,
                              const char *template_name)
 {
    static const char status[] =
-      "500 Internal JunkBuster Proxy Error";
+      "500 Internal Privoxy Error";
    static const char body_prefix[] =
       "<html>\r\n"
-      "<head><title>500 Internal JunkBuster Proxy Error</title></head>\r\n"
+      "<head><title>500 Internal Privoxy Error</title></head>\r\n"
       "<body>\r\n"
-      "<h1>500 Internal JunkBuster Proxy Error</h1>\r\n"
-      "<p>JunkBuster encountered an error while processing your request:</p>\r\n"
+      "<h1>500 Internal Privoxy Error</h1>\r\n"
+      "<p>Privoxy encountered an error while processing your request:</p>\r\n"
       "<p><b>Could not load template file <code>";
    static const char body_suffix[] =
       "</code></b></p>\r\n"
@@ -940,10 +930,10 @@ jb_err cgi_error_no_template(struct client_state *csp,
       "<p>If you are the proxy administrator, please put the required file "
       "in the <code><i>(confdir)</i>/templates</code> directory.  The "
       "location of the <code><i>(confdir)</i></code> directory "
-      "is specified in the main JunkBuster <code>config</code> "
-      "file.  (It's typically the JunkBuster install directory"
+      "is specified in the main Privoxy <code>config</code> "
+      "file.  (It's typically the Privoxy install directory"
 #ifndef _WIN32
-      ", or <code>/etc/junkbuster/</code>"
+      ", or <code>/etc/privoxy/</code>"
 #endif /* ndef _WIN32 */
       ").</p>\r\n"
       "</body>\r\n"
@@ -1115,7 +1105,7 @@ struct http_response *finish_http_response(struct http_response *rsp)
    }
    if (!err)
    {
-      sprintf(buf, "Content-Length: %d", rsp->content_length);
+      sprintf(buf, "Content-Length: %d", (int)rsp->content_length);
       err = enlist(rsp->headers, buf);
    }
 
@@ -1136,7 +1126,7 @@ struct http_response *finish_http_response(struct http_response *rsp)
    {
       /*
        * Set Expires to about 10 min into the future so it'll get reloaded
* occasionally, e.g. if IJB gets upgraded.
        */
 
       if (!err)
@@ -1136,7 +1126,7 @@ struct http_response *finish_http_response(struct http_response *rsp)
       /*
        * Set Expires to about 10 min into the future so it'll get reloaded
-       * occasionally, e.g. if IJB gets upgraded.
+       * occasionally, e.g. if Privoxy gets upgraded.
        */
 